
clear all
set more off
set scheme lean1
graph set eps fontface Times


***   directories
local dir = "...\replication"


***   How many workers earn the minimum wage?   ***

use "`dir'\data\raw\minwage-by-state.dta", clear
sort state year month

tempfile temp
save "`temp'", replace

foreach yr of numlist 1979/2012 {

	use "`dir'\data\raw\morg_cleaned_`yr'", replace

	* All workers
	drop if state==53
	keep if age>=18 & age<=64

	replace hr_wage = (round((hr_wage/gdp),.01))

	sort state hr_wage

	sort state year month
	qui merge m:1 state year month using `temp'
	keep if _merge==3

	replace minw = log(minw+.02)
	replace hr_wage = log(hr_wage)

	gen sub_hrs = wgt_hrs*(hr_wage<=minw)
	gen all_hrs = wgt_hrs if hr_wage!=. 

	gen sub = wgt*(hr_wage<=minw)
	gen all = wgt if hr_wage!=. 

	collapse (sum) sub_hrs all_hrs sub all, by(year)
	sort year

	tempfile temp`yr'
	save `temp`yr'', replace
}

use `temp1979'
foreach yr of numlist 1980/2012 {
	append using `temp`yr''
}

gen     share_hrs = sub_hrs/all_hrs
replace share_hrs = share_hrs*100

twoway line share_hrs year, aspectratio(.8) scale(1.7) xtitle("") ytitle("%") ylabel(0(2)10, grid glp(dot)) xlabel(1980(10)2010, grid glp(dot)) ymtick(##2) xmtick(##10) graphregion(margin(-20 -5 0 0))
graph export "`dir'\figure\figure1a.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure1a.jpg", as(jpg) quality(90) replace
