
clear all
set more off
set scheme lean1
graph set eps fontface Times


***   directories
local dir = "...\replication"


***   Who earns the minimum wage?   ***

use "`dir'\data\raw\minwage-by-state.dta", clear
sort state year month

tempfile temp
save "`temp'", replace

foreach yr of numlist 1979/2012 {

	use "`dir'\data\raw\morg_cleaned_`yr'", replace

	drop if state==53
	keep if age>=18 & age<=64

	replace hr_wage=(round((hr_wage/gdp),.01))

	sort state hr_wage

	sort state year month
	qui merge m:1 state year month using `temp'
	keep if _merge==3

	replace minw    = log(minw+.02)
	replace hr_wage = log(hr_wage)

	* Minimum wage workers
	keep if hr_wage<=minw

	gen sub_l_hrs = wgt_hrs*(educomp<=12)
	gen sub_y_hrs = wgt_hrs*(age<=24)
	gen sub_f_hrs = wgt_hrs*(sex==2)
	gen sub_a_hrs = wgt_hrs*(educomp<=12|age<=24|sex==2)
	gen all_hrs   = wgt_hrs if hr_wage!=. 

	gen sub_l = wgt*(educomp<=12)
	gen sub_y = wgt*(age<=24)
	gen sub_f = wgt*(sex==2)
	gen sub_a = wgt*(educomp<=12|age<=24|sex==2)
	gen all   = wgt if hr_wage!=. 

	collapse (sum) sub_l sub_y sub_f sub_a all ///
				   sub_l_hrs sub_y_hrs sub_f_hrs sub_a_hrs all_hrs, by(year)
	sort year
	tempfile temp`yr'
	save `temp`yr'', replace
}

use `temp1979'
foreach yr of numlist 1980/2012 {
	append using `temp`yr''
}

gen share_l_hrs = sub_l_hrs/all_hrs
gen share_y_hrs = sub_y_hrs/all_hrs
gen share_f_hrs = sub_f_hrs/all_hrs
gen share_a_hrs = sub_a_hrs/all_hrs

foreach x in a l y f {
	replace share_`x'_hrs = share_`x'_hrs*100
}

twoway line share_a_hrs share_l_hrs share_f_hrs share_y_hrs year, aspectratio(.8) scale(1.2) xtitle("") ytitle("%") ylabel(20(20)100, grid glp(dot) labsize(medlarge)) xlabel(1980(10)2010, grid glp(dot) labsize(medlarge)) ymtick(##2) xmtick(##10) ///
       legend(label(1 "Any of following") label(2 "Less educated") label(3 "Female") label(4 "Young") position(6) rows(2)) graphregion(margin(-20 -5 0 0))
graph export "`dir'\figure\figure1b.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure1b.jpg", as(jpg) quality(90) replace
