
clear all
set more off
set scheme lean1
graph set eps fontface Times


* Figures 5, 6. 7; 16, 17, 18, 19


***   directories
local dir = "...\replication"


***   =50 if imputed, =0 if not imputed
local thre = 50


***   Construct confidence intervals & bands
if `thre'!=0 {
	use "`dir'\data\boot\step2_boot.dta", clear
}
if `thre'==0 {
	use "`dir'\data\boot\boot0\step2_boot.dta", clear
}
reshape long b0_q b1_q b2_q b3_q b4_q b5_q b6_q b7_q, i(n) j(q)
if `thre'!=0 {
	merge m:1 q using "`dir'\data\est\step2.dta"
}
if `thre'==0 {
	merge m:1 q using "`dir'\data\est\est0\step2.dta"
}
drop _merge
drop b1_q b2_q b3_q b4_q b1 b2 b3 b4
sort q n
**  Confidence intervals: b_t
foreach j of numlist 0 5 6 7 {
	rename b`j'_q b`j'_boot
}
foreach j of numlist 0 5 6 7 {
	qui g b`j'_lb = .
	qui g b`j'_ub = .
	forvalues q = 4/97 {
		_pctile b`j'_boot if q==`q', p(2.5 97.5) /*p(.5 99.5)*/
		qui replace b`j'_lb = r(r1) if q==`q'
		qui replace b`j'_ub = r(r2) if q==`q'
	}
}
if `thre'==0 {
	collapse b0 b5 b6 b7 ///
			 b0_lb b5_lb b6_lb b7_lb b0_ub b5_ub b6_ub b7_ub ///
		   , by(q)
}
if `thre'!=0 {
	**  Confidence bands: b_t
	foreach j of numlist 0 5 6 7 {

		* step 1: scaling parameters 
		qui g scal`j' = . 

		forvalues q = 4/97 {
			_pctile b`j'_boot if q==`q', p(25 75)
			qui replace scal`j' = ( r(r2) - r(r1) ) /( invnormal(0.75) - invnormal(0.25) ) if q ==`q'
		}
		
		* step 2: test stat (sup)
		qui g t_temp`j' = .
		
		* - test stat
		qui replace t_temp`j' = abs( b`j'_boot - b`j') / scal`j'
		
		* - sup over quantiles
		egen t_sup`j' = max(t_temp`j'), by(n)
		
		* step 3: critical values
		* - t_sup`j' has the supremum value for each bootstrap but contains
		*   the same values over quantiles. Select one quantile and calculate 
		*   critical values.
		_pctile t_sup`j' if q==50, p(95)
		g cv`j' = r(r1)
		
		* step 3: confidence bound 
		g b`j'_lcb = b`j' - cv`j' * scal`j'
		g b`j'_ucb = b`j' + cv`j' * scal`j'
		drop scal`j' t_temp`j' t_sup`j' cv`j'
		
	}
	collapse b0 b5 b6 b7 ///
			 b0_lb b5_lb b6_lb b7_lb b0_ub b5_ub b6_ub b7_ub ///
			 b0_lcb b5_lcb b6_lcb b7_lcb b0_ucb b5_ucb b6_ucb b7_ucb ///
		   , by(q)
}
g zero = 0
replace q = q/100
**  confidence intervals
* constant
twoway (rarea b0_lb b0_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
       (line b0 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
	 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
if `thre'!=0 {
	graph export "`dir'\figure\figure5a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure5a.jpg", as(jpg) quality(90) replace
}
if `thre'==0 {
	graph export "`dir'\figure\figure16a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure16a.jpg", as(jpg) quality(90) replace
}
* education
twoway (rarea b6_lb b6_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
       (line b6 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
	 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
if `thre'!=0 {
	graph export "`dir'\figure\figure5b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure5b.jpg", as(jpg) quality(90) replace
}
if `thre'==0 {
	graph export "`dir'\figure\figure16b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure16b.jpg", as(jpg) quality(90) replace
}
* experience
twoway (rarea b7_lb b7_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
       (line b7 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
	 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:3} + 2 {it:{&beta}}{subscript:4} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
if `thre'!=0 {
	graph export "`dir'\figure\figure5c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure5c.jpg", as(jpg) quality(90) replace
}
if `thre'==0 {
	graph export "`dir'\figure\figure16c.eps", as(eps) preview(off) replace
}
* gender
twoway (rarea b5_lb b5_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
       (line b5 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
	 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:5}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.2(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
if `thre'!=0 {
	graph export "`dir'\figure\figure5d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure5d.jpg", as(jpg) quality(90) replace
}
if `thre'==0 {
	graph export "`dir'\figure\figure16d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure16d.jpg", as(jpg) quality(90) replace
}
if `thre'!=0 {
	**  confidence bands
	* constant
	twoway (rarea b0_lcb b0_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b0 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure17a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure17a.jpg", as(jpg) quality(90) replace
	* education
	twoway (rarea b6_lcb b6_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b6 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure17b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure17b.jpg", as(jpg) quality(90) replace
	* experience
	twoway (rarea b7_lcb b7_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b7 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:3} + 2 {it:{&beta}}{subscript:4} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure17c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure17c.jpg", as(jpg) quality(90) replace
	* gender
	twoway (rarea b5_lcb b5_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b5 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:5}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.2(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure17d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure17d.jpg", as(jpg) quality(90) replace


	***   Construct confidence intervals and bands
	use "`dir'\data\boot\step2_boot_ll.dta", clear
	reshape long b0_q  b1_q  b2_q  b3_q  b4_q  b5_q  b6_q  b7_q  ///
				 b0f_q b1f_q b2f_q b3f_q b4f_q b5f_q b6f_q b7f_q ///
		  , i(n) j(q)
	merge m:1 q using "`dir'\data\est\step2_ll.dta"
	drop _merge
	forvalues j = 0/7 {
		rename b`j'_f b`j'f
	}
	drop b1_q b2_q b3_q b4_q b1 b2 b3 b4 b1f_q b2f_q b3f_q b4f_q b1f b2f b3f b4f
	sort q n
	**  Confidence intervals: b_t-1 + b_t, b_t+1
	foreach j of numlist 0 5 6 7 {
		rename b`j'_q  b`j'_boot
		rename b`j'f_q b`j'f_boot
	}
	foreach j of numlist 0 5 6 7 {
		qui g b`j'_lb  = .
		qui g b`j'_ub  = .
		qui g b`j'f_lb = .
		qui g b`j'f_ub = .
		forvalues q = 4/97 {
			_pctile b`j'_boot if q==`q', p(2.5 97.5) /*p(.5 99.5)*/
			qui replace b`j'_lb = r(r1) if q==`q'
			qui replace b`j'_ub = r(r2) if q==`q'
			_pctile b`j'f_boot if q==`q', p(2.5 97.5) /*p(.5 99.5)*/
			qui replace b`j'f_lb = r(r1) if q==`q'
			qui replace b`j'f_ub = r(r2) if q==`q'
		}
	}
	**  confidence bands: b_t-1 + b_t, b_t
	foreach j of numlist 0 5 6 7 {

		* step 1: scaling parameters 
		qui g scal`j'  = . 
		qui g scal`j'f = . 

		forvalues q = 4/97 {
			_pctile b`j'_boot if q==`q', p(25 75)
			qui replace scal`j' = ( r(r2) - r(r1) ) /( invnormal(0.75) - invnormal(0.25) ) if q ==`q'
			_pctile b`j'f_boot if q==`q', p(25 75)
			qui replace scal`j'f = ( r(r2) - r(r1) ) /( invnormal(0.75) - invnormal(0.25) ) if q ==`q'
		}
		
		* step 2: test stat (sup)
		qui g t_temp`j' = .
		qui g t_temp`j'f = .
		
		* - test stat
		qui replace t_temp`j' = abs( b`j'_boot - b`j') / scal`j'
		qui replace t_temp`j'f = abs( b`j'f_boot - b`j'f) / scal`j'f
		
		* - sup over quantiles
		egen t_sup`j' = max(t_temp`j'), by(n)
		egen t_sup`j'f = max(t_temp`j'f), by(n)
		
		* step 3: critical values
		* - t_sup`j' has the supremum value for each bootstrap but contains
		*   the same values over quantiles. Select one quantile and calculate
		*   critical values.
		_pctile t_sup`j' if q==50, p(95)
		g cv`j' = r(r1)
		_pctile t_sup`j'f if q==50, p(95)
		g cv`j'f = r(r1)
		
		* step 3: confidence bound 
		g b`j'_lcb = b`j' - cv`j' * scal`j'
		g b`j'_ucb = b`j' + cv`j' * scal`j'
		g b`j'f_lcb = b`j'f - cv`j'f * scal`j'f
		g b`j'f_ucb = b`j'f + cv`j'f * scal`j'f
		drop scal`j' t_temp`j' t_sup`j' cv`j' scal`j'f t_temp`j'f t_sup`j'f cv`j'f
		
	}
	
	collapse b0 b5 b6 b7 b0f b5f b6f b7f ///
			 b0_lb b5_lb b6_lb b7_lb b0_ub b5_ub b6_ub b7_ub ///
			 b0_lcb b5_lcb b6_lcb b7_lcb b0_ucb b5_ucb b6_ucb b7_ucb ///
			 b0f_lb b5f_lb b6f_lb b7f_lb b0f_ub b5f_ub b6f_ub b7f_ub ///
			 b0f_lcb b5f_lcb b6f_lcb b7f_lcb b0f_ucb b5f_ucb b6f_ucb b7f_ucb ///
		   , by(q)
	g zero = 0
	replace q = q/100
	
	**  Confidence intervals: b_t-1 + b_t
	* intercept
	twoway (rarea b0_lb b0_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b0 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure6a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure6a.jpg", as(jpg) quality(90) replace
	* education
	twoway (rarea b6_lb b6_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b6 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2, +1} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure6b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure6b.jpg", as(jpg) quality(90) replace
	* experience
	twoway (rarea b7_lb b7_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b7 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:3} + 2 {it:{&beta}}{subscript:4} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure6c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure6c.jpg", as(jpg) quality(90) replace
	* male
	twoway (rarea b5_lb b5_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b5 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:5}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.3(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure6d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure6d.jpg", as(jpg) quality(90) replace
	**  Confidence intervals: b_t+1
	* intercept
	twoway (rarea b0f_lb b0f_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b0f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure7a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure7a.jpg", as(jpg) quality(90) replace
	* education
	twoway (rarea b6f_lb b6f_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b6f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2, +1} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure7b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure7b.jpg", as(jpg) quality(90) replace
	* experience
	twoway (rarea b7f_lb b7f_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b7f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:3, +1} + 2 {it:{&beta}}{subscript:4, +1} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure7c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure7c.jpg", as(jpg) quality(90) replace
	* male
	twoway (rarea b5f_lb b5f_ub q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b5f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:5, +1}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.2(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure7d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure7d.jpg", as(jpg) quality(90) replace
	**  Confidence bands: b_t-1 + b_t
	* intercept
	twoway (rarea b0_lcb b0_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b0 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure18a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure18a.jpg", as(jpg) quality(90) replace
	* education
	twoway (rarea b6_lcb b6_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b6 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2, +1} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure18b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure18b.jpg", as(jpg) quality(90) replace
	* experience
	twoway (rarea b7_lcb b7_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b7 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:3} + 2 {it:{&beta}}{subscript:4} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure18c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure18c.jpg", as(jpg) quality(90) replace
	* male
	twoway (rarea b5_lcb b5_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b5 q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{&sum} {it:{&beta}}{subscript:5}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.3(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure18d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure18d.jpg", as(jpg) quality(90) replace
	**  Confidence bands: b_t+1
	* intercept
	twoway (rarea b0f_lcb b0f_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b0f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:0}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-1.5(.5)2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Intercept")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure19a.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure19a.jpg", as(jpg) quality(90) replace
	* education
	twoway (rarea b6f_lcb b6f_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b6f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:1} + 2 {it:{&beta}}{subscript:2, +1} {it:educ}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.1(.05).05, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Education (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure19b.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure19b.jpg", as(jpg) quality(90) replace
	* experience
	twoway (rarea b7f_lcb b7f_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b7f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:3, +1} + 2 {it:{&beta}}{subscript:4, +1} {it:exper}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.015(.005).005, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Experience (partial effect)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure19c.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure19c.jpg", as(jpg) quality(90) replace
	* male
	twoway (rarea b5f_lcb b5f_ucb q if q>=.04 & q<=.97, fcolor(gs13) lcolor(gs13)) ///
		   (line b5f q if q>=.04 & q<=.97, lpattern(solid) lwidth(medthick)) (line zero q, lpattern(shortdash)) ///
		 , legend(off) xtitle("Quantile", size(medsmall)) ytitle(""/*"{it:{&beta}}{subscript:5, +1}"*/) xlabel(0(.1)1, grid glp(dot)) ymtick(##2) xmtick(##10) ylabel(-.2(.1).2, grid glp(dot)) aspectratio(.8) scale(1.7) /*title("Gender (male)")*/ graphregion(margin(zero))
	graph export "`dir'\figure\figure19d.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure19d.jpg", as(jpg) quality(90) replace
}
