
clear all
set more off
set scheme lean1
graph set eps fontface Times


* Figures 8, 10, 12, 14


***   directories
local dir = "...\replication"


**  Changes in minimum wage
use "`dir'\data\est\step1_all.dta", clear
xtset state year
g       Dlnmw = lnmw - L10.lnmw if year==1989
replace Dlnmw = lnmw - L23.lnmw if year==2012
sum Dlnmw [aw=sumwt] if year==1989
sum Dlnmw [aw=sumwt] if year==2012
g       Dlnmw_t0 = Dlnmw[_n+10] if year==1979
replace Dlnmw_t0 = Dlnmw[_n+23] if year==1989
g       lnmw_t0  = lnmw         if year==1989
replace lnmw_t0  = lnmw[_n-23]  if year==2012
* education and experience wage differentials
forvalues Q = 4/97 {
	g a6_q`Q' = a1_q`Q'+2*a2_q`Q'*x
	g a7_q`Q' = a3_q`Q'+2*a4_q`Q'*x
}
**  changes in coefficients due to minimum wage changes
forvalues j = 0/5 {
	forvalues Q = 4/97 {
		di "j=`j', q=`Q'"
		qui xi: reg a`j'_q`Q' lnmw i.year i.state*year [aw=sumwt], cluster(state)
		qui g Da`j'_mw_q`Q'    = _b[lnmw]*Dlnmw    if year==1989|year==2012
		qui g Da`j'_mw_t0_q`Q' = _b[lnmw]*Dlnmw_t0 if year==1979|year==1989
	}
}
forvalues Q = 4/97 {
	qui g Da6_mw_q`Q'    = Da1_mw_q`Q'   +2*Da2_mw_q`Q'   *s if year==1989|year==2012
	qui g Da6_mw_t0_q`Q' = Da1_mw_t0_q`Q'+2*Da2_mw_t0_q`Q'*s if year==1989|year==2012
	qui g Da7_mw_q`Q'    = Da3_mw_q`Q'   +2*Da4_mw_q`Q'   *x if year==1989|year==2012
	qui g Da7_mw_t0_q`Q' = Da3_mw_t0_q`Q'+2*Da4_mw_t0_q`Q'*x if year==1989|year==2012
}
drop _Iyear_1980-_IstaXyear_95
keep if year==1979|year==1989|year==2012
**  actual and counterfactual changes in coefficients
forvalues j = 0/7 {
	forvalues Q = 4/97 {
		qui g Da`j'_q`Q' = a`j'_q`Q' - a`j'_q`Q'[_n-1] if state==state[_n-1]
		qui g Da`j'_cf_q`Q' = Da`j'_q`Q' - Da`j'_mw_q`Q'
	}
}
keep state year sumwt s s2 x x2 g a0_* a1_* a2_* a3_* a4_* a5_* a6_* a7_* Da0_* Da1_* Da2_* Da3_* Da4_* Da5_* Da6_* Da7_* lnmw lnmw_t0 Dlnmw Dlnmw_t0
qui compress
save "`dir'\data\est\counterf.dta", replace


**  Changes in hourly wages due to the minimum wage
* evaluate by (s, x, g)
use "`dir'\data\est\counterf.dta", clear
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
		
			di "s=`s', x=`x', g=`g'"
			use "`dir'\data\est\counterf.dta", clear
			qui keep if year==1989|year==2012
			
			foreach Q of numlist 5 10 20 30 40 50 60 70 80 90 {
				* actual and counterfactual wages
				qui g lnw_cf_q`Q'  = (a0_q`Q'-Da0_mw_q`Q') + (a1_q`Q'-Da1_mw_q`Q')*`s' + (a2_q`Q'-Da2_mw_q`Q')*`s'^2 + (a3_q`Q'-Da3_mw_q`Q')*`x' + (a4_q`Q'-Da4_mw_q`Q')*`x'^2 + (a5_q`Q'-Da5_mw_q`Q')*`g'
				qui g lnw_hat_q`Q' =  a0_q`Q'              +  a1_q`Q'*`s'              +  a2_q`Q'*`s'^2              +  a3_q`Q'*`x'              +  a4_q`Q'*`x'^2              +  a5_q`Q'*`g'
				* censoring
				qui replace lnw_cf_q`Q'  = lnmw - Dlnmw if lnw_cf_q`Q'  <= lnmw - Dlnmw
				qui replace lnw_hat_q`Q' = lnmw         if lnw_hat_q`Q' <= lnmw
				qui g Dlnw_mw_q`Q' = lnw_hat_q`Q' - lnw_cf_q`Q'
				drop lnw_cf_q`Q' lnw_hat_q`Q'
			}
			keep state year sumwt Dlnw_mw_q5 Dlnw_mw_q10 Dlnw_mw_q20 Dlnw_mw_q30 Dlnw_mw_q40 Dlnw_mw_q50 Dlnw_mw_q60 Dlnw_mw_q70 Dlnw_mw_q80 Dlnw_mw_q90
			qui g s = `s'
			qui g x = `x'
			qui g g = `g'
			qui save "`dir'\data\est\s`s'x`x'g`g'.dta", replace
		}
	}
}
* append
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
			if `s'==12 & `x'==0 & `g'==0 {
				use "`dir'\data\est\s`s'x`x'g`g'.dta", clear
			}
			else {
				append using "`dir'\data\est\s`s'x`x'g`g'.dta"
			}
		}
	}
}
compress
*aorder
order state year sumwt s x g Dlnw_mw_q5-Dlnw_mw_q90
save "`dir'\data\est\wagediff.dta", replace
* erase
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		foreach g of numlist 0 1 {
			erase "`dir'\data\est\s`s'x`x'g`g'.dta"
		}
	}
}


***   Changes in between-group differentials
use "`dir'\data\est\wagediff.dta", clear
reshape long Dlnw_mw_q, i(state year sumwt s x g) j(pct)
foreach a in Dlnw_mw {
	rename `a'_q `a'_s
}
reshape wide Dlnw_mw_s, i(state year sumwt pct x g) j(s)
foreach a in Dlnw_mw {
	foreach s of numlist 12 16 {
		rename `a'_s`s' `a'_s`s'_x
	}
}
reshape wide Dlnw_mw_s12_x-Dlnw_mw_s16_x, i(state year sumwt pct g) j(x)
foreach a in Dlnw_mw {
	foreach s of numlist 12 16 {
		foreach x of numlist 0 5 10 25 {
			rename `a'_s`s'_x`x' `a'_s`s'_x`x'_g
		}
	}
}
reshape wide Dlnw_mw_s12_x0_g-Dlnw_mw_s16_x25_g, i(state year sumwt pct) j(g)
** educational wage differential
foreach x of numlist 0 5 10 25 {
	foreach g of numlist 0 1 {
		g Dlnw_mw_s1612_x`x'_g`g' = 100*(Dlnw_mw_s16_x`x'_g`g' - Dlnw_mw_s12_x`x'_g`g')
	}
}
** experience wage differential
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		g Dlnw_mw_s`s'_x2505_g`g' = 100*(Dlnw_mw_s`s'_x25_g`g' - Dlnw_mw_s`s'_x5_g`g')
	}
}
** gender wage differential
foreach s of numlist 12 16 {
	foreach x of numlist 0 5 10 25 {
		g Dlnw_mw_s`s'_x`x'_g10 = 100*(Dlnw_mw_s`s'_x`x'_g1 - Dlnw_mw_s`s'_x`x'_g0)
	}
}
collapse (mean) Dlnw_mw_s1612_x0_g0-Dlnw_mw_s16_x25_g10 ///
         (max)  Dlnw_mw_max_s1612_x0_g0 =Dlnw_mw_s1612_x0_g0  Dlnw_mw_max_s1612_x0_g1 =Dlnw_mw_s1612_x0_g1  Dlnw_mw_max_s1612_x5_g0 =Dlnw_mw_s1612_x5_g0 ///
		        Dlnw_mw_max_s1612_x5_g1 =Dlnw_mw_s1612_x5_g1  Dlnw_mw_max_s1612_x10_g0=Dlnw_mw_s1612_x10_g0 Dlnw_mw_max_s1612_x10_g1=Dlnw_mw_s1612_x10_g1 ///
				Dlnw_mw_max_s1612_x25_g0=Dlnw_mw_s1612_x25_g0 Dlnw_mw_max_s1612_x25_g1=Dlnw_mw_s1612_x25_g1 Dlnw_mw_max_s12_x2505_g0=Dlnw_mw_s12_x2505_g0 ///
				Dlnw_mw_max_s12_x2505_g1=Dlnw_mw_s12_x2505_g1 Dlnw_mw_max_s16_x2505_g0=Dlnw_mw_s16_x2505_g0 Dlnw_mw_max_s16_x2505_g1=Dlnw_mw_s16_x2505_g1 ///
				Dlnw_mw_max_s12_x0_g10  =Dlnw_mw_s12_x0_g10   Dlnw_mw_max_s12_x5_g10  =Dlnw_mw_s12_x5_g10  ///
				Dlnw_mw_max_s12_x10_g10 =Dlnw_mw_s12_x10_g10  Dlnw_mw_max_s12_x25_g10 =Dlnw_mw_s12_x25_g10 ///
				Dlnw_mw_max_s16_x0_g10  =Dlnw_mw_s16_x0_g10   Dlnw_mw_max_s16_x5_g10  =Dlnw_mw_s16_x5_g10  ///
				Dlnw_mw_max_s16_x10_g10 =Dlnw_mw_s16_x10_g10  Dlnw_mw_max_s16_x25_g10 =Dlnw_mw_s16_x25_g10 ///
         (min)  Dlnw_mw_min_s1612_x0_g0 =Dlnw_mw_s1612_x0_g0  Dlnw_mw_min_s1612_x0_g1 =Dlnw_mw_s1612_x0_g1  Dlnw_mw_min_s1612_x5_g0 =Dlnw_mw_s1612_x5_g0 ///
		        Dlnw_mw_min_s1612_x5_g1 =Dlnw_mw_s1612_x5_g1  Dlnw_mw_min_s1612_x10_g0=Dlnw_mw_s1612_x10_g0 Dlnw_mw_min_s1612_x10_g1=Dlnw_mw_s1612_x10_g1 ///
				Dlnw_mw_min_s1612_x25_g0=Dlnw_mw_s1612_x25_g0 Dlnw_mw_min_s1612_x25_g1=Dlnw_mw_s1612_x25_g1 Dlnw_mw_min_s12_x2505_g0=Dlnw_mw_s12_x2505_g0 ///
				Dlnw_mw_min_s12_x2505_g1=Dlnw_mw_s12_x2505_g1 Dlnw_mw_min_s16_x2505_g0=Dlnw_mw_s16_x2505_g0 Dlnw_mw_min_s16_x2505_g1=Dlnw_mw_s16_x2505_g1 ///
				Dlnw_mw_min_s12_x0_g10  =Dlnw_mw_s12_x0_g10   Dlnw_mw_min_s12_x5_g10  =Dlnw_mw_s12_x5_g10  ///
				Dlnw_mw_min_s12_x10_g10 =Dlnw_mw_s12_x10_g10  Dlnw_mw_min_s12_x25_g10 =Dlnw_mw_s12_x25_g10 ///
				Dlnw_mw_min_s16_x0_g10  =Dlnw_mw_s16_x0_g10   Dlnw_mw_min_s16_x5_g10  =Dlnw_mw_s16_x5_g10  ///
				Dlnw_mw_min_s16_x10_g10 =Dlnw_mw_s16_x10_g10  Dlnw_mw_min_s16_x25_g10 =Dlnw_mw_s16_x25_g10 ///
[pw=sumwt], by(year pct)
save "`dir'\data\est\wagediff_bg.dta", replace
* figures
keep if year==2012
g decile = _n
foreach x of numlist 5 10 {
	foreach g of numlist 0 1 {
		twoway (bar Dlnw_mw_s1612_x`x'_g`g' decile, color(gs10)) (rcap Dlnw_mw_max_s1612_x`x'_g`g' Dlnw_mw_min_s1612_x`x'_g`g' decile, color(gs6)), legend(off) ytitle("") xtitle("Quantile", size(medsmall)) ylabel(-25(5)0, grid glp(dot)) ///
		       xlabels(1 ".05" 2 ".1" 3 ".2" 4 ".3" 5 ".4" 6 ".5" 7 ".6" 8 ".7" 9 ".8" 10 ".9") aspectratio(.8) scale(1.7) /*title("{it:exper} = `x', {it:male} = `g'")*/ graphregion(margin(-15 -10 0 0))
		graph export "`dir'\figure\figure8_x`x'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure8_x`x'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach g of numlist 0 1 {
		twoway (bar Dlnw_mw_s`s'_x2505_g`g' decile, color(gs10)) (rcap Dlnw_mw_max_s`s'_x2505_g`g' Dlnw_mw_min_s`s'_x2505_g`g' decile, color(gs6)), legend(off) ytitle("") xtitle("Quantile", size(medsmall)) ylabel(-25(5)0, grid glp(dot)) ///
		       xlabels(1 ".05" 2 ".1" 3 ".2" 4 ".3" 5 ".4" 6 ".5" 7 ".6" 8 ".7" 9 ".8" 10 ".9") aspectratio(.8) scale(1.7) /*title("{it:educ} = `s', {it:male} = `g'")*/ graphregion(margin(-15 -10 0 0))
		graph export "`dir'\figure\figure10_s`s'_g`g'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure10_s`s'_g`g'.jpg", as(jpg) quality(90) replace
	}
}
foreach s of numlist 12 16 {
	foreach x of numlist 5 10 {
		twoway (bar Dlnw_mw_s`s'_x`x'_g10 decile, color(gs10)) (rcap Dlnw_mw_max_s`s'_x`x'_g10 Dlnw_mw_min_s`s'_x`x'_g10 decile, color(gs6)), legend(off) ytitle("") xtitle("Quantile", size(medsmall)) ylabel(-25(5)0, grid glp(dot)) ///
		       xlabels(1 ".05" 2 ".1" 3 ".2" 4 ".3" 5 ".4" 6 ".5" 7 ".6" 8 ".7" 9 ".8" 10 ".9") aspectratio(.8) scale(1.7) /*title("{it:educ} = `s', {it:exper} = `x'")*/ graphregion(margin(-15 -10 0 0))
		graph export "`dir'\figure\figure12_s`s'_x`x'.eps", as(eps) preview(off) replace
		graph export "`dir'\figure\figure12_s`s'_x`x'.jpg", as(jpg) quality(90) replace
	}
}


**   Changes in within-group differentials
use "`dir'\data\est\wagediff.dta", clear
* within-group wage differential
g Dlnw_mw_q9010 = 100*(Dlnw_mw_q90 - Dlnw_mw_q10)
g Dlnw_mw_q5010 = 100*(Dlnw_mw_q50 - Dlnw_mw_q10)
g Dlnw_mw_q5020 = 100*(Dlnw_mw_q50 - Dlnw_mw_q20)
collapse (mean) Dlnw_mw_q9010 Dlnw_mw_q5010 Dlnw_mw_q5020 ///
         (max)  Dlnw_mw_max_q9010=Dlnw_mw_q9010 Dlnw_mw_max_q5010=Dlnw_mw_q5010 Dlnw_mw_max_q5020=Dlnw_mw_q5020 ///
         (min)  Dlnw_mw_min_q9010=Dlnw_mw_q9010 Dlnw_mw_min_q5010=Dlnw_mw_q5010 Dlnw_mw_min_q5020=Dlnw_mw_q5020 ///
[pw=sumwt], by(year s x g)
save "`dir'\data\est\wagediff_wg.dta", replace
* figures
keep if year==2012
keep if x<15
**  males
preserve
keep if g==1
* 90-10
sort s x
g group = _n
foreach k of numlist 1/10 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
graph twoway (bar Dlnw_mw_q9010 group, color(gs10)) (rcap Dlnw_mw_max_q9010 Dlnw_mw_min_q9010 group, color(gs6)), scale(1.3) legend(off) aspectratio(.8) ylabel(-35(5)5, grid glp(dot) labsize(large)) ytitle("", size(large)) xtitle("({it:educ}, {it:exper})", size(large)) /*title("90-10, males")*/ ///
             xlabels(1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')") graphregion(margin(-15 -10 0 0))
graph export "`dir'\figure\figure14_9010_g1.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure14_9010_g1.jpg", as(jpg) quality(90) replace
drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort s x
	g group = _n
	foreach k of numlist 1/10 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	graph twoway (bar Dlnw_mw_q50`Q' group, color(gs10)) (rcap Dlnw_mw_max_q50`Q' Dlnw_mw_min_q50`Q' group, color(gs6)), scale(1.3) legend(off) aspectratio(.8) ylabel(-35(5)5, grid glp(dot) labsize(large)) ytitle("", size(large)) xtitle("({it:educ}, {it:exper})", size(large)) /*title("50-`Q', males")*/ ///
                  xlabels(1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')") graphregion(margin(-15 -10 0 0))
	graph export "`dir'\figure\figure14_50`Q'_g1.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure14_50`Q'_g1.jpg", as(jpg) quality(90) replace
	drop group
}
**  females
restore
keep if g==0
* 90-10
sort s x
g group = _n
foreach k of numlist 1/10 {
	local s`k' = s[`k']
	local x`k' = x[`k']
}
graph twoway (bar Dlnw_mw_q9010 group, color(gs10)) (rcap Dlnw_mw_max_q9010 Dlnw_mw_min_q9010 group, color(gs6)), scale(1.3) legend(off) aspectratio(.8) ylabel(-35(5)5, grid glp(dot) labsize(large)) ytitle("", size(large)) xtitle("({it:educ}, {it:exper})", size(large)) /*title("90-10, females")*/ ///
             xlabels(1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')") graphregion(margin(-15 -10 0 0))
graph export "`dir'\figure\figure14_9010_g0.eps", as(eps) preview(off) replace
graph export "`dir'\figure\figure14_9010_g0.jpg", as(jpg) quality(90) replace
drop group
* 50-10, 50-20
foreach Q of numlist 10 20 {
	sort s x
	g group = _n
	foreach k of numlist 1/10 {
		local s`k' = s[`k']
		local x`k' = x[`k']
	}
	graph twoway (bar Dlnw_mw_q50`Q' group, color(gs10)) (rcap Dlnw_mw_max_q50`Q' Dlnw_mw_min_q50`Q' group, color(gs6)), scale(1.3) legend(off) aspectratio(.8) ylabel(-35(5)5, grid glp(dot) labsize(large)) ytitle("", size(large)) xtitle("({it:educ}, {it:exper})", size(large)) /*title("50-`Q', females")*/ ///
                  xlabels(1 "(`s1',`x1')" 2 "(`s2',`x2')" 3 "(`s3',`x3')" 4 "(`s4',`x4')" 5 "(`s5',`x5')" 6 "(`s6',`x6')") graphregion(margin(-15 -10 0 0))
	graph export "`dir'\figure\figure14_50`Q'_g0.eps", as(eps) preview(off) replace
	graph export "`dir'\figure\figure14_50`Q'_g0.jpg", as(jpg) quality(90) replace
	drop group
}
